pilot.api.compute.api.PilotComputeDescription

Package pilot :: Package api :: Package compute :: Module api :: Class PilotComputeDescription |

# Class PilotComputeDescription

source code

PilotComputeDescription (PCD).

A PilotComputeDescription is a based on the attributes defined on the SAGA Job Description.

The PilotComputeDescription is used by the application to specify what kind of PilotJobs it requires.

Example:

        pilot_compute_description = {
                        "service_url": 'fork://localhost',
                        "number_of_processes": 1,
                        "working_directory": "/tmp/pilot-compute/",
                        'affinity_datacenter_label': "eu-de-south",
                        'affinity_machine_label': "mymachine-1"
                       }

Attention: The PilotComputeDescription is mapped 1:1 to the underlying SAGA-Python (Bliss) job description, which is used for launching the pilot. Depending on the resource, it is required to add additional attributes, e.g. some XSEDE/Torque resources require the specification of both number_of_process and processes_per_node:

Example:

         pilot_compute_description = {
                        "service_url": 'pbs+ssh://india.futuregrid.org',
                        "number_of_processes": 8,
                        "processes_per_node":8,
                        "working_directory": "/N/u/luckow",
                        'affinity_datacenter_label': "us-east-indiana",
                        'affinity_machine_label': "india"
                       }

Instance Methods
    new empty dictionary
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__setattr__(self, attr, value) x.__setattr__('name', value) <==> x.name = value | source code
__getattr__(self, attr) | source code
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setitem__`, `__sizeof__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`, `viewitems`, `viewkeys`, `viewvalues` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__str__`, `__subclasshook__`

Class Variables
Inherited from `dict`: `__hash__`

Properties
| affinity_datacenter_label
| affinity_machine_label
| error
| file_transfer
| input
| number_of_processes
| output
| processes_per_host
| project
| queue
| service_url
| wall_time_limit
| working_directory
Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Returns:
    new empty dictionary
Overrides: object.__init__ (inherited documentation)

### __setattr__(self, attr, value) | source code
x.__setattr__('name', value) <==> x.name = value Overrides: object.__setattr__ (inherited documentation)